==> webgui_7.9.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_StoryTopic.pm <==
package WebGUI::i18n::English::Asset_StoryTopic;
use strict;

our $I18N = {

    'assetName' => {
        message => q|Story Topic|,
        context => q|An Asset that displays stories based on keywords.|,
        lastUpdated => 0
    },

    'stories per topic' => {
        message => q|Stories Per Topic|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'stories per topic help' => {
        message => q|The number of stories displayed in RSS and Atom feeds from this Story Topic, and when viewing the Topic directly.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'stories short' => {
        message => q|Stories Per Page|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'stories short help' => {
        message => q|The number of stories displayed on a page.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'story template' => {
        message => q|Story Template|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'story template help' => {
        message => q|The Template used to display Story assets from this Story Topic.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'template' => {
        message => q|Main Template|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'template help' => {
        message => q|The Template used to display the Story Topic.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'story_loop' => {
        message => q|A loop containing the most recent stories for this topic.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'url' => {
        message => q|The URL to view a story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'title' => {
        message => q|The title of a story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'creationDate' => {
        message => q|The epoch date when this story was created, or submitted, to its Story Archive.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'deleteIcon' => {
        message => q|An icon to delete this story.  If the user is not allowed to delete the story, or their UI level is set too low, this variable will be empty.|,
        context => q|Template variable.|,
        lastUpdated => 1248191573,
    },

    'editIcon' => {
        message => q|An icon to edit this story.  If the user is not allowed to edit the story, or their UI level is set too low, this variable will be empty.|,
        context => q|Template variable.|,
        lastUpdated => 1248191575,
    },

    'topStoryUrl' => {
        message => q|The URL to view the top story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryTitle' => {
        message => q|The title of the top story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStorySubtitle' => {
        message => q|The subtitle of the top story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryCreationDate' => {
        message => q|The epoch date when the top story was created, or submitted, to its Story Archive.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageCaption' => {
        message => q|The Caption of the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageByline' => {
        message => q|The Byline of the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageAlt' => {
        message => q|The alternate image text for the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageTitle' => {
        message => q|The image title for the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageLink' => {
        message => q|The link for the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageUrl' => {
        message => q|The URL to the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'standAlone' => {
        message => q|This variable will be true if the Story Topic is being viewed directly, by its URL.  Otherwise, if it is viewed as part of a Page Layout or other Container, it will be false.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'view template' => {
        message => q|View Story Topic Template|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'storytopic asset template variables title' => {
        message => q|Story Topic Asset Template Variables|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'rssUrl' => {
        message => q|The URL for the RSS feed for this Story Topic.|,
        context => q|Template variable.|,
        lastUpdated => 1248191627,
    },

    'atomUrl' => {
        message => q|The URL for the Atom feed for this Story Topic.|,
        context => q|Template variable.|,
        lastUpdated => 1248191629,
    },

    'Read more stories' => {
        message => q|Read more stories.|,
        context => q|Template label.|,
        lastUpdated => 1252202057,
    },

};

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_StoryTopic.pm <==
package WebGUI::i18n::English::Asset_StoryTopic;
use strict;

our $I18N = {

    'assetName' => {
        message => q|Story Topic|,
        context => q|An Asset that displays stories based on keywords.|,
        lastUpdated => 0
    },

    'stories per topic' => {
        message => q|Stories Per Topic|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'stories per topic help' => {
        message => q|The number of stories displayed in RSS and Atom feeds from this Story Topic, and when viewing the Topic directly.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'stories short' => {
        message => q|Stories Per Page|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'stories short help' => {
        message => q|The number of stories displayed on a page.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'story template' => {
        message => q|Story Template|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'story template help' => {
        message => q|The Template used to display Story assets from this Story Topic.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'template' => {
        message => q|Main Template|,
        context => q|Label in the edit screen and template.|,
        lastUpdated => 0
    },

    'template help' => {
        message => q|The Template used to display the Story Topic.|,
        context => q|Hoverhelp in the edit screen and template.|,
        lastUpdated => 0
    },

    'story_loop' => {
        message => q|A loop containing the most recent stories for this topic.  In addition to the listed variables, all the view template variables from Story are available.|,
        context => q|Template variable.|,
        lastUpdated => 1294679882,
    },

    'url' => {
        message => q|The URL to view a story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'title' => {
        message => q|The title of a story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'creationDate' => {
        message => q|The epoch date when this story was created, or submitted, to its Story Archive.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'deleteIcon' => {
        message => q|An icon to delete this story.  If the user is not allowed to delete the story, or their UI level is set too low, this variable will be empty.|,
        context => q|Template variable.|,
        lastUpdated => 1248191573,
    },

    'editIcon' => {
        message => q|An icon to edit this story.  If the user is not allowed to edit the story, or their UI level is set too low, this variable will be empty.|,
        context => q|Template variable.|,
        lastUpdated => 1248191575,
    },

    'topStory' => {
        message => 'Variable containing the same kind of values as story_loop, but for the topStory.  Accessible via topStory.hasPhotos, etc.',
        context => 'Template variable.',
        lastUpdated => 1294761543,
    },

    'topStoryUrl' => {
        message => q|The URL to view the top story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryTitle' => {
        message => q|The title of the top story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStorySubtitle' => {
        message => q|The subtitle of the top story.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryCreationDate' => {
        message => q|The epoch date when the top story was created, or submitted, to its Story Archive.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageCaption' => {
        message => q|The Caption of the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageByline' => {
        message => q|The Byline of the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageAlt' => {
        message => q|The alternate image text for the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageTitle' => {
        message => q|The image title for the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageLink' => {
        message => q|The link for the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'topStoryImageUrl' => {
        message => q|The URL to the first photo for the top story, if it exists.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'standAlone' => {
        message => q|This variable will be true if the Story Topic is being viewed directly, by its URL.  Otherwise, if it is viewed as part of a Page Layout or other Container, it will be false.|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'view template' => {
        message => q|View Story Topic Template|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'storytopic asset template variables title' => {
        message => q|Story Topic Asset Template Variables|,
        context => q|Template variable.|,
        lastUpdated => 0,
    },

    'rssUrl' => {
        message => q|The URL for the RSS feed for this Story Topic.|,
        context => q|Template variable.|,
        lastUpdated => 1248191627,
    },

    'atomUrl' => {
        message => q|The URL for the Atom feed for this Story Topic.|,
        context => q|Template variable.|,
        lastUpdated => 1248191629,
    },

    'Read more stories' => {
        message => q|Read more stories.|,
        context => q|Template label.|,
        lastUpdated => 1252202057,
    },

};

1;
